@@ -1,4 +1,5 @@
 #!perl -w
+use 5.010;
 use strict;
 
 use Text::Xslate;
@@ -9,18 +10,16 @@ use FindBin qw($Bin);
 
 use Config; printf "Perl/%vd %s\n", $^V, $Config{archname};
 foreach my $mod(qw(Text::Xslate Text::MicroTemplate)){
-    print $mod, '/', $mod->VERSION, "\n";
+    say $mod, '/', $mod->VERSION;
 }
-my $path = "$Bin/template";
 
 my $mt = Text::MicroTemplate::File->new(
-    include_path => [$path],
+    include_path => ["$Bin/template"],
     cache        => 2,
 );
 my $tx = Text::Xslate->new(
-    path      => [$path],
-    cache_dir => '.xslate_cache',
-    cache     => 2,
+    path  => ["$Bin/template"],
+    cache => 2,
 );
 
 my %vars = (
